@@ -112,12 +112,19 @@ function initLevel() {
     if (GCompris.ApplicationSettings.isAudioVoicesEnabled &&
             GCompris.DownloadManager.haveLocalResource(
                 GCompris.DownloadManager.getVoicesResourceForLocale(locale))) {
-        items.audioVoices.silence(100)
-        playLetter(currentLetter)
+        appendVoice();
     }
     items.buttonsBlocked = false;
 }
 
+function appendVoice() {
+    if(GCompris.DownloadManager.areVoicesRegistered(items.locale)) {
+        playLetter(currentLetter);
+    } else {
+        items.voiceTimer.start();
+    }
+}
+
 function calculateFrequency() {
     var freq = [];
     for(var i = 0; i < words.length; i++) {
@@ -162,7 +169,7 @@ function playLetter(letter) {
 
 function nextLevel() {
     items.score.stopWinAnimation();
-    items.audioVoices.clearQueue()
+    items.audioVoices.clearQueue();
     items.currentLevel = Core.getNextLevel(items.currentLevel, maxLevel);
     items.score.currentSubLevel = 0;
     initLevel();
@@ -170,13 +177,14 @@ function nextLevel() {
 
 function previousLevel() {
     items.score.stopWinAnimation();
-    items.audioVoices.clearQueue()
+    items.audioVoices.clearQueue();
     items.currentLevel = Core.getPreviousLevel(items.currentLevel, maxLevel);
     items.score.currentSubLevel = 0;
     initLevel();
 }
 
 function nextSubLevel() {
+    items.audioVoices.clearQueue();
     if( items.score.currentSubLevel >= maxSubLevel) {
         items.bonus.good("flower");
     } else {
