@@ -201,6 +201,7 @@ function initLevel() {
     if(!items)
         return
 
+    items.activityStopped = false
     loopsNumber = 1
     destroyInstructionObjects()
 
@@ -384,16 +385,18 @@ function previousLevel() {
     initLevel();
 }
 
-function repositionObjectsOnWidthChanged(factor) {
+function repositionObjectsOnWidthChanged() {
     resetTux = true
-    if(items && !items.activityStopped)
+    if(items && items.activityStopped == false) {
         initLevel()
+    }
 }
 
-function repositionObjectsOnHeightChanged(factor) {
+function repositionObjectsOnHeightChanged() {
     resetTux = true
-    if(items && !items.activityStopped)
+    if(items && items.activityStopped == false) {
         initLevel()
+    }
 }
 
 function reloadLevel() {
