@@ -17,11 +17,9 @@
 #include "ApplicationSettings.h"
 
 #include <QObject>
-#include <QLocale>
-#include <QQmlEngine>
 #include <QSslSocket>
-#include <QtGlobal>
 
+class QQmlEngine;
 class QQuickWindow;
 
 /**
@@ -254,7 +252,7 @@ public:
     static QObject *applicationInfoProvider(QQmlEngine *engine,
                                             QJSEngine *scriptEngine);
     static void setWindow(QQuickWindow *window);
-    explicit ApplicationInfo(QObject *parent = 0);
+    explicit ApplicationInfo(QObject *parent = nullptr);
     ~ApplicationInfo();
     int applicationWidth() const { return m_applicationWidth; }
     void setApplicationWidth(const int newWidth);
@@ -354,7 +352,7 @@ public:
 
     /// @endcond
 
-public slots:
+public Q_SLOTS:
     /**
      * Returns the resource root-paths used for GCompris resources.
      * First look in a local folder if exists, else will look into the rcc files.
@@ -426,7 +424,7 @@ public slots:
 protected:
     qreal getSizeWithRatio(const qreal height) { return ratio() * height; }
 
-signals:
+Q_SIGNALS:
     void applicationWidthChanged();
     void portraitModeChanged();
     void ratioChanged();
